OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Не можу писати у каталог \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Зазвичай це можна виправити, надавши веб-серверу права на запис в теці конфігурації",
    "See %s" : "Переглянути %s",
    "Sample configuration detected" : "Виявлено приклад конфігурації",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Було виявлено, що приклад конфігурації було скопійовано. Це може нашкодити вашій системі та не підтримується. Будь ласка, зверніться до документації перед внесенням змін в файл config.php",
    "PHP %s or higher is required." : "Необхідно PHP %s або вище",
    "PHP with a version lower than %s is required." : "Потрібна версія PHP нижче %s ",
    "Following databases are supported: %s" : "Підтримуються наступні сервери баз даних: %s",
    "The command line tool %s could not be found" : "Утиліту командного рядка %s не знайдено",
    "The library %s is not available." : "Бібліотека %s недоступна.",
    "Following platforms are supported: %s" : "Підтримуються наступні платформи: %s",
    "Authentication" : "Автентифікація",
    "Unknown filetype" : "Невідомий тип файлу",
    "Invalid image" : "Невірне зображення",
    "today" : "сьогодні",
    "yesterday" : "вчора",
    "_%n day ago_::_%n days ago_" : ["%n день тому","%n днів тому","%n днів тому","%n днів тому"],
    "last month" : "минулого місяця",
    "last year" : "минулого року",
    "_%n year ago_::_%n years ago_" : ["%n рік тому","%n років тому","%n років тому","%n років тому"],
    "seconds ago" : "секунди тому",
    "File name is a reserved word" : "Ім’я файлу є зарезервованим словом",
    "File name contains at least one invalid character" : "Ім’я файлу містить принаймні один некоректний символ",
    "File name is too long" : "Ім’я файлу занадто довге",
    "Dot files are not allowed" : "Файли які починаються з крапки не допустимі",
    "Empty filename is not allowed" : "Порожні імена файлів не допускаються",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Додаток \"%s\" не може бути встановлений через те, що файл appinfo не може бути прочитано.",
    "__language_name__" : "Українська",
    "Help" : "Допомога",
    "Apps" : "Додатки",
    "Settings" : "Налаштування",
    "Log out" : "Вихід",
    "Users" : "Користувачі",
    "Unknown user" : "Невідомий користувач",
    "Sharing" : "Поділитись",
    "Security" : "Безпека",
    "Personal info" : "Особиста інформація",
    "%s enter the database username and name." : "%s введіть назву бази даних та ім'я користувача.",
    "%s enter the database username." : "%s введіть ім'я користувача бази даних.",
    "%s enter the database name." : "%s введіть назву бази даних.",
    "%s you may not use dots in the database name" : "%s не можна використовувати крапки в назві бази даних",
    "Oracle connection could not be established" : "Не можемо з'єднатися з Oracle ",
    "Oracle username and/or password not valid" : "Oracle ім'я користувача та/або пароль не дійсні",
    "PostgreSQL username and/or password not valid" : "PostgreSQL ім'я користувача та/або пароль не дійсні",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X не підтримується і %s не буде коректно працювати на цій платформі. Випробовуєте на свій риск!",
    "For the best results, please consider using a GNU/Linux server instead." : "Для кращих результатів розгляньте можливість використання GNU/Linux серверу",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Здається що екземпляр цього %s працює в 32-бітному PHP середовищі і open_basedir повинен бути налаштований в php.ini. Це призведе до проблем з файлами більше 4 ГБ і це дуже не рекомендується.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Будь ласка, видаліть параметр open_basedir у вашому php.ini або перейдіть на 64-бітний PHP.",
    "Set an admin username." : "Встановіть ім'я адміністратора.",
    "Set an admin password." : "Встановіть пароль адміністратора.",
    "Can't create or write into the data directory %s" : "Неможливо створити або записати каталог даних %s",
    "Invalid Federated Cloud ID" : "Неправильний Об'єднаний Хмарний Ідентіфікатор ",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Backend загального доступу %s повинен реалізовувати інтерфейс OCP\\Share_Backend",
    "Sharing backend %s not found" : "Backend загального доступу %s не знайдено",
    "Sharing backend for %s not found" : "Бекенд загального доступу для %s не знайдено",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s надав Вам доступ »%2$s« та хоче додати:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s надав Вам доступ »%2$s« та хоче додати",
    "»%s« added a note to a file shared with you" : "»%s« додав нотатку до опублікованого файлу",
    "You are not allowed to share %s" : "Вам заборонено поширювати %s",
    "Expiration date is in the past" : "Дата закінчення в минулому",
    "%1$s shared »%2$s« with you" : "%1$s надав Вам доступ до »%2$s«",
    "%1$s shared »%2$s« with you." : "%1$s надав Вам доступ до »%2$s«.",
    "Click the button below to open it." : "Для відкриття натисніть кнопку нижче.",
    "Could not find category \"%s\"" : "Не вдалося знайти категорію \"%s\"",
    "Sunday" : "Неділя",
    "Monday" : "Понеділок",
    "Tuesday" : "Вівторок",
    "Wednesday" : "Середа",
    "Thursday" : "Четвер",
    "Friday" : "П'ятниця",
    "Saturday" : "Субота",
    "Sun." : "Нд.",
    "Mon." : "Пн.",
    "Tue." : "Вт.",
    "Wed." : "Ср.",
    "Thu." : "Чт.",
    "Fri." : "Пт.",
    "Sat." : "Сб.",
    "Su" : "Нд.",
    "Mo" : "Пн.",
    "Tu" : "Вт.",
    "We" : "Ср.",
    "Th" : "Чт.",
    "Fr" : "Пт.",
    "Sa" : "Сб.",
    "January" : "Січень",
    "February" : "Лютий",
    "March" : "Березень",
    "April" : "Квітень",
    "May" : "Травень",
    "June" : "Червень",
    "July" : "Липень",
    "August" : "Серпень",
    "September" : "Вересень",
    "October" : "Жовтень",
    "November" : "Листопад",
    "December" : "Грудень",
    "Jan." : "Січ.",
    "Feb." : "Лют.",
    "Mar." : "Бер.",
    "Apr." : "Кві.",
    "May." : "Тра.",
    "Jun." : "Чер.",
    "Jul." : "Лип.",
    "Aug." : "Сер.",
    "Sep." : "Вер.",
    "Oct." : "Жов.",
    "Nov." : "Лис.",
    "Dec." : "Гру.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Тільки такі символи допускаються в імені користувача: \"a-z\", \"A-Z\", \"0-9\", і \"_.@-'\"",
    "A valid username must be provided" : "Потрібно задати вірне ім'я користувача",
    "Username contains whitespace at the beginning or at the end" : "Ім'я користувача містить символ пробілу в початку або в кінці",
    "A valid password must be provided" : "Потрібно задати вірний пароль",
    "The username is already being used" : "Ім'я користувача вже використовується",
    "User disabled" : "Користувач виключений",
    "Login canceled by app" : "Вхід скасовано додатком",
    "a safe home for all your data" : "безпечний дім для ваших даних",
    "File is currently busy, please try again later" : "Файл на разі зайнятий, будь ласка, спробуйте пізніше",
    "Can't read file" : "Не можливо прочитати файл",
    "Application is not enabled" : "Додаток не увімкнений",
    "Authentication error" : "Помилка автентифікації",
    "Token expired. Please reload page." : "Строк дії токена скінчився. Будь ласка, перезавантажте сторінку.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Не встановлено драйвер бази даних (sqlite, mysql, or postgresql).",
    "Cannot write into \"config\" directory" : "Не можу писати у теку \"config\"",
    "Cannot write into \"apps\" directory" : "Не можу писати у теку \"apps\"",
    "Setting locale to %s failed" : "Установка локалі %s не вдалася",
    "Please install one of these locales on your system and restart your webserver." : "Встановіть один із цих мовних пакетів в вашу систему і перезапустіть веб-сервер.",
    "Please ask your server administrator to install the module." : "Будь ласка, зверніться до адміністратора, щоб встановити модуль.",
    "PHP module %s not installed." : "%s модуль PHP не встановлено.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Параметр PHP \"%s\" не встановлено в \"%s\".",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload налаштовано як \"%s\" замість очікуваного значення \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Для виправлення змініть <code>mbstring.func_overload</code> на <code>0</code> у вашому php.ini",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Необхідно libxml2 версії принаймні 2.7.0. На разі встановлена %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Що виправити це оновіть версію libxml2 та перезапустіть веб-сервер.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Схоже, що PHP налаштовано на вичищення блоків вбудованої документації. Це зробить кілька основних додатків недоступними.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Це, ймовірно, обумовлено використанням кеша/прискорювача такого як Zend OPcache або eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Модулі PHP були встановлені, але вони все ще перераховані як відсутні?",
    "Please ask your server administrator to restart the web server." : "Будь ласка, зверніться до адміністратора, щоб перезавантажити сервер.",
    "PostgreSQL >= 9 required" : "Потрібно PostgreSQL> = 9",
    "Please upgrade your database version" : "Оновіть версію бази даних",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Змініть права доступу на 0770, щоб інші користувачі не могли отримати список файлів цього каталогу.",
    "Check the value of \"datadirectory\" in your configuration" : "Перевірте значення \"datadirectory\" у своїй конфігурації",
    "Could not obtain lock type %d on \"%s\"." : "Не вдалося отримати блокування типу %d для \"%s\"",
    "Storage unauthorized. %s" : "Сховище не авторизовано. %s",
    "Storage incomplete configuration. %s" : "Неповна конфігурація сховища. %s",
    "Storage connection error. %s" : "Помилка з'єднання зі сховищем. %s",
    "Storage is temporarily not available" : "Сховище тимчасово недоступне",
    "Storage connection timeout. %s" : "Час під'єднання до сховища вичерпався. %s",
    "Create" : "Створити",
    "Delete" : "Видалити",
    "Share" : "Поділитися",
    "Unlimited" : "Необмежено",
    "Verifying …" : "Перевірка ...",
    "Verify" : "Перевірити",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Не вдалося поділитися %s, загальний доступ не допускає публікації з елементів типу %i",
    "Sharing %s failed, because the file does not exist" : "Не вдалося поділитися %s, оскільки файл не існує",
    "Sharing %s failed, because you can not share with yourself" : "Не вдалося поділитися %s, оскільки ви не можете ділитись самі з собою",
    "You need to provide a password to create a public link, only protected links are allowed" : "Вам необхідно задати пароль для створення публічного посилання. Дозволені лише захищені посилання",
    "Sharing %s failed, because sharing with links is not allowed" : "Не вдалося поділитися %s, оскільки публічний доступ через посилання заборонений",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Неможливо встановити дату закінчення. Загальні ресурси не можуть застаріти пізніше %s з моменту їх публікації.",
    "Cannot set expiration date. Expiration date is in the past" : "Неможливо встановити дату закінчення. Дата закінчення в минулому.",
    "Sharing failed, because the user %s is the original sharer" : "Не вдалося поділитися, оскільки %s є тим хто поділився з самого початку",
    "Sharing %s failed, because resharing is not allowed" : "Не вдалося поділитися %s, перевідкриття доступу заборонено",
    "Sharing %s failed, because the file could not be found in the file cache" : "Не вдалося поділитися %s, елемент не знайдено у файловому кеші."
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
